Class: XAeonAgents::Agents::Readme::ContributingAgent

Inherits:
ComposableAgents::Cline::Agent
  • Object
show all
Includes:
XAeonAgents::AgentDefaults
Defined in:
lib/x_aeon_agents/agents/readme/contributing_agent.rb

Overview

Agent responsible for generating the "Contributing" section of a README.

Instance Method Summary collapse

Methods included from XAeonAgents::AgentDefaults

#new_agent, prepended, singleton_session_id

Constructor Details

#initialize(**agent_params) ⇒ ContributingAgent

Constructor

Parameters:

  • agent_params (Hash{Symbol => Object})

    Extra agent parameters



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/x_aeon_agents/agents/readme/contributing_agent.rb', line 23

def initialize(**agent_params)
  super(
    name: 'Contributing',
    objective: <<~EO_OBJECTIVE,
    constraints: <<~EO_CONSTRAINTS,
      - The required output artifact content should only contain the required content, without additional header or title.
      - Do not explain or describe the artifact content: only provide the content as required.
      - Only focus on the specific scope of the required documentation required.
        Other agents will generate other sections of the README.
        Do not try to document other parts.
      - Do not describe the technical setup or prequisites, as they are already covered by other sections.
      - Do not cover how to develop in this project: it is already covered in other sections.
    EO_CONSTRAINTS
    **agent_params
  )
end

Instance Method Details

#output_artifacts_contractsHash{Symbol => Object}

Define output artifacts contracts

Returns:

  • (Hash{Symbol => Object})

    Set of output artifacts description, per artifact name



11
12
13
14
15
16
17
18
# File 'lib/x_aeon_agents/agents/readme/contributing_agent.rb', line 11

def output_artifacts_contracts
  super.merge(
    contributing: {
      description: 'The "Contributing" section content in Markdown format, explaining how to contribute to the project',
      type: :markdown
    }
  )
end