Class: XAeonAgents::Agents::Readme::PublicApiAgent

Inherits:
ComposableAgents::Cline::Agent
  • Object
show all
Includes:
XAeonAgents::AgentDefaults
Defined in:
lib/x_aeon_agents/agents/readme/public_api_agent.rb

Overview

Agent responsible for generating the "Public API" section of a README.

Instance Method Summary collapse

Methods included from XAeonAgents::AgentDefaults

#new_agent, prepended, singleton_session_id

Constructor Details

#initialize(**agent_params) ⇒ PublicApiAgent

Constructor

Parameters:

  • agent_params (Hash{Symbol => Object})

    Extra agent parameters



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/x_aeon_agents/agents/readme/public_api_agent.rb', line 23

def initialize(**agent_params)
  super(
    name: 'Public API',
    objective: <<~EO_OBJECTIVE,
    constraints: <<~EO_CONSTRAINTS,
      - The required output artifact content should only contain the required content, without additional header or title.
      - Do not explain or describe the artifact content: only provide the content as required.
      - Only focus on the specific scope of the required documentation required.
        Other agents will generate other sections of the README.
        Do not try to document other parts.
      - Only document public API entry points: executables and library public methods belonging to yarn `Public API` group.
    EO_CONSTRAINTS
    **agent_params
  )
end

Instance Method Details

#output_artifacts_contractsHash{Symbol => Object}

Define output artifacts contracts

Returns:

  • (Hash{Symbol => Object})

    Set of output artifacts description, per artifact name



11
12
13
14
15
16
17
18
# File 'lib/x_aeon_agents/agents/readme/public_api_agent.rb', line 11

def output_artifacts_contracts
  super.merge(
    public_api: {
      description: 'The "Public API" section content in Markdown format, describing the public API surface of the project',
      type: :markdown
    }
  )
end