Class: XAeonAgents::Agents::DocumenterAgent
- Inherits:
-
ComposableAgents::Cline::Agent
- Object
- ComposableAgents::Cline::Agent
- XAeonAgents::Agents::DocumenterAgent
- Includes:
- XAeonAgents::AgentDefaults
- Defined in:
- lib/x_aeon_agents/agents/documenter_agent.rb
Overview
Agent responsible for updating documentation after a new development
Instance Method Summary collapse
-
#initialize(**agent_params) ⇒ DocumenterAgent
constructor
Constructor.
-
#input_artifacts_contracts ⇒ Hash{Symbol => Object}
Define input artifacts contracts.
Methods included from XAeonAgents::AgentDefaults
#new_agent, prepended, singleton_session_id
Constructor Details
#initialize(**agent_params) ⇒ DocumenterAgent
Constructor
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/x_aeon_agents/agents/documenter_agent.rb', line 21 def initialize(**agent_params) super( name: 'Documenter', objective: 'Ensure documentation reflects the current product behavior and usage after a new development.', constraints: <<~EO_CONSTRAINTS, - Only update documentation files. - Do NOT change any code or test. - NEVER document the fact that a change happened. - NEVER explain that something was removed, renamed, or fixed. - Documentation describes the CURRENT STATE only. - Documentation is NOT a changelog. EO_CONSTRAINTS skills: %w[ applying-ruby-conventions applying-test-conventions updating-doc enforcing-project-rules ], **agent_params ) end |
Instance Method Details
#input_artifacts_contracts ⇒ Hash{Symbol => Object}
Define input artifacts contracts
10 11 12 13 14 15 16 |
# File 'lib/x_aeon_agents/agents/documenter_agent.rb', line 10 def input_artifacts_contracts super.merge( requirements: 'The initial requirements', plan: 'Implementation plan that introduced features and fixes to be documented', files_diffs: 'Full list of files changes and differences that have been done to implement the initial requirements following the implementation plan' ) end |