Class: XAeonAgents::Agents::Readme::AboutAnalyzerAgent
- Inherits:
-
ComposableAgents::Cline::Agent
- Object
- ComposableAgents::Cline::Agent
- XAeonAgents::Agents::Readme::AboutAnalyzerAgent
- Includes:
- XAeonAgents::AgentDefaults
- Defined in:
- lib/x_aeon_agents/agents/readme/about_analyzer_agent.rb
Overview
Agent responsible for generating the "About" section of a README.
Instance Method Summary collapse
-
#initialize(**agent_params) ⇒ AboutAnalyzerAgent
constructor
Constructor.
-
#output_artifacts_contracts ⇒ Hash{Symbol => Object}
Define output artifacts contracts.
Methods included from XAeonAgents::AgentDefaults
#new_agent, prepended, singleton_session_id
Constructor Details
#initialize(**agent_params) ⇒ AboutAnalyzerAgent
Constructor
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/x_aeon_agents/agents/readme/about_analyzer_agent.rb', line 32 def initialize(**agent_params) super( name: 'About Analyzer', objective: <<~EO_OBJECTIVE, constraints: <<~EO_CONSTRAINTS, - The required output artifacts content should only contain the required content, without additional header or title. - Do not explain or describe the artifact contents: only provide the content as required. - Only focus on the specific scope of the required documentation required. Other agents will generate other sections of the README. Do not try to document other parts. EO_CONSTRAINTS **agent_params ) end |
Instance Method Details
#output_artifacts_contracts ⇒ Hash{Symbol => Object}
Define output artifacts contracts
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 |
# File 'lib/x_aeon_agents/agents/readme/about_analyzer_agent.rb', line 12 def output_artifacts_contracts super.merge( about: { description: 'The "About" section content in Markdown format, describing the project goal, problem it solves, and its interface', type: :markdown }, name: { description: 'This project\'s name', type: :text }, description: { description: 'This project\'s description in 1 line', type: :markdown } ) end |